from codecs import open
from setuptools import setup, find_packages

with open('README.md') as readme_file:
    README = readme_file.read()


VERSION = '0.1.2'
DESCRIPTION = 'Enhanced options payoff diagram charting based on opstrat library'
URL = 'https://github.com/pursual/superOpStrat'

# Setting up
setup(
    name="superOpStrat",
    version=VERSION,
    author="Tony G",
    author_email="<pursual@gmail.com>",
    description=DESCRIPTION,
    long_description_content_type='text/markdown',
    long_description=README,
    url=URL,
    license='MIT',
    packages=find_packages(exclude=["tests", "*.tests", "*.tests.*", "tests.*"]),
    python_requires='>=3.6',
    install_requires=['matplotlib', 
                      'pandas', 
                      'numpy',
                      'scipy',
                      'seaborn',
                      'yfinance'],
    keywords=['python', 
              'options', 
              'finance', 
              'opstrat', 
              'data visualization', 
              'stock market'],
    classifiers=[
            "Development Status :: 4 - Beta",
            "Intended Audience :: Developers",
            "Intended Audience :: Education",
            "Intended Audience :: Science/Research",
            "Intended Audience :: Financial and Insurance Industry",
            "License :: OSI Approved :: MIT License",
            "Natural Language :: English",
            "Operating System :: OS Independent",
            "Topic :: Scientific/Engineering :: Visualization",
            'Topic :: Scientific/Engineering :: Information Analysis',
            "Topic :: Office/Business :: Financial :: Investment",
            "Topic :: Office/Business :: Financial",
            "Programming Language :: Python :: 3"]
)
